@@ -50,7 +50,7 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public boolean deletesAreDetected(int type) throws SQLException {
+    public boolean deletesAreDetected(final int type) throws SQLException {
         return false;
     }
 
@@ -60,15 +60,15 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getAttributes(String catalog, String schemaPattern,
-            String typeNamePattern, String attributeNamePattern)
+    public ResultSet getAttributes(final String catalog, final String schemaPattern,
+            final String typeNamePattern, final String attributeNamePattern)
             throws SQLException {
         return null;
     }
 
     @Override
-    public ResultSet getBestRowIdentifier(String catalog, String schema,
-            String table, int scope, boolean nullable) throws SQLException {
+    public ResultSet getBestRowIdentifier(final String catalog, final String schema,
+            final String table, final int scope, final boolean nullable) throws SQLException {
         return null;
     }
 
@@ -88,14 +88,14 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
     
     @Override
-    public ResultSet getColumnPrivileges(String catalog, String schema,
-            String table, String columnNamePattern) throws SQLException {
+    public ResultSet getColumnPrivileges(final String catalog, final String schema,
+            final String table, final String columnNamePattern) throws SQLException {
         return null;
     }
 
     @Override
-    public ResultSet getColumns(String catalog, String schemaPattern,
-            String tableNamePattern, String columnNamePattern)
+    public ResultSet getColumns(final String catalog, final String schemaPattern,
+            final String tableNamePattern, final String columnNamePattern)
             throws SQLException {
         return null;
     }
@@ -106,9 +106,9 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getCrossReference(String parentCatalog,
-            String parentSchema, String parentTable, String foreignCatalog,
-            String foreignSchema, String foreignTable) throws SQLException {
+    public ResultSet getCrossReference(final String parentCatalog,
+            final String parentSchema, final String parentTable, final String foreignCatalog,
+            final String foreignSchema, final String foreignTable) throws SQLException {
         return null;
     }
 
@@ -158,7 +158,7 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getExportedKeys(String catalog, String schema, String table)
+    public ResultSet getExportedKeys(final String catalog, final String schema, final String table)
             throws SQLException {
         return null;
     }
@@ -174,14 +174,14 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getImportedKeys(String catalog, String schema, String table)
+    public ResultSet getImportedKeys(final String catalog, final String schema, final String table)
             throws SQLException {
         return null;
     }
 
     @Override
-    public ResultSet getIndexInfo(String catalog, String schema, String table,
-            boolean unique, boolean approximate) throws SQLException {
+    public ResultSet getIndexInfo(final String catalog, final String schema, final String table,
+            final boolean unique, final boolean approximate) throws SQLException {
         return null;
     }
 
@@ -301,14 +301,14 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getPrimaryKeys(String catalog, String schema, String table)
+    public ResultSet getPrimaryKeys(final String catalog, final String schema, final String table)
             throws SQLException {
         return null;
     }
 
     @Override
-    public ResultSet getProcedureColumns(String catalog, String schemaPattern,
-            String procedureNamePattern, String columnNamePattern)
+    public ResultSet getProcedureColumns(final String catalog, final String schemaPattern,
+            final String procedureNamePattern, final String columnNamePattern)
             throws SQLException {
         return null;
     }
@@ -319,8 +319,8 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getProcedures(String catalog, String schemaPattern,
-            String procedureNamePattern) throws SQLException {
+    public ResultSet getProcedures(final String catalog, final String schemaPattern,
+            final String procedureNamePattern) throws SQLException {
         return null;
     }
 
@@ -360,14 +360,14 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getSuperTables(String catalog, String schemaPattern,
-            String tableNamePattern) throws SQLException {
+    public ResultSet getSuperTables(final String catalog, final String schemaPattern,
+            final String tableNamePattern) throws SQLException {
         return null;
     }
 
     @Override
-    public ResultSet getSuperTypes(String catalog, String schemaPattern,
-            String typeNamePattern) throws SQLException {
+    public ResultSet getSuperTypes(final String catalog, final String schemaPattern,
+            final String typeNamePattern) throws SQLException {
         return null;
     }
 
@@ -377,8 +377,8 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getTablePrivileges(String catalog, String schemaPattern,
-            String tableNamePattern) throws SQLException {
+    public ResultSet getTablePrivileges(final String catalog, final String schemaPattern,
+            final String tableNamePattern) throws SQLException {
         return null;
     }
 
@@ -388,8 +388,8 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getTables(String catalog, String schemaPattern,
-            String tableNamePattern, String[] types) throws SQLException {
+    public ResultSet getTables(final String catalog, final String schemaPattern,
+            final String tableNamePattern, final String[] types) throws SQLException {
         return null;
     }
 
@@ -404,8 +404,8 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getUDTs(String catalog, String schemaPattern,
-            String typeNamePattern, int[] types) throws SQLException {
+    public ResultSet getUDTs(final String catalog, final String schemaPattern,
+            final String typeNamePattern, final int[] types) throws SQLException {
         return null;
     }
 
@@ -420,13 +420,13 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getVersionColumns(String catalog, String schema,
-            String table) throws SQLException {
+    public ResultSet getVersionColumns(final String catalog, final String schema,
+            final String table) throws SQLException {
         return null;
     }
 
     @Override
-    public boolean insertsAreDetected(int type) throws SQLException {
+    public boolean insertsAreDetected(final int type) throws SQLException {
         return false;
     }
 
@@ -471,32 +471,32 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public boolean othersDeletesAreVisible(int type) throws SQLException {
+    public boolean othersDeletesAreVisible(final int type) throws SQLException {
         return false;
     }
 
     @Override
-    public boolean othersInsertsAreVisible(int type) throws SQLException {
+    public boolean othersInsertsAreVisible(final int type) throws SQLException {
         return false;
     }
 
     @Override
-    public boolean othersUpdatesAreVisible(int type) throws SQLException {
+    public boolean othersUpdatesAreVisible(final int type) throws SQLException {
         return false;
     }
 
     @Override
-    public boolean ownDeletesAreVisible(int type) throws SQLException {
+    public boolean ownDeletesAreVisible(final int type) throws SQLException {
         return false;
     }
 
     @Override
-    public boolean ownInsertsAreVisible(int type) throws SQLException {
+    public boolean ownInsertsAreVisible(final int type) throws SQLException {
         return false;
     }
 
     @Override
-    public boolean ownUpdatesAreVisible(int type) throws SQLException {
+    public boolean ownUpdatesAreVisible(final int type) throws SQLException {
         return false;
     }
 
@@ -596,7 +596,7 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public boolean supportsConvert(int fromType, int toType)
+    public boolean supportsConvert(final int fromType, final int toType)
             throws SQLException {
         return false;
     }
@@ -759,19 +759,19 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public boolean supportsResultSetConcurrency(int type, int concurrency)
+    public boolean supportsResultSetConcurrency(final int type, final int concurrency)
             throws SQLException {
         return false;
     }
 
     @Override
-    public boolean supportsResultSetHoldability(int holdability)
+    public boolean supportsResultSetHoldability(final int holdability)
             throws SQLException {
         return false;
     }
 
     @Override
-    public boolean supportsResultSetType(int type) throws SQLException {
+    public boolean supportsResultSetType(final int type) throws SQLException {
         return false;
     }
 
@@ -846,7 +846,7 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public boolean supportsTransactionIsolationLevel(int level)
+    public boolean supportsTransactionIsolationLevel(final int level)
             throws SQLException {
         return false;
     }
@@ -867,7 +867,7 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public boolean updatesAreDetected(int type) throws SQLException {
+    public boolean updatesAreDetected(final int type) throws SQLException {
         return false;
     }
 
@@ -884,12 +884,12 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     /* JDBC_4_ANT_KEY_BEGIN */
 
     @Override
-    public boolean isWrapperFor(Class<?> iface) throws SQLException {
+    public boolean isWrapperFor(final Class<?> iface) throws SQLException {
         return false;
     }
 
     @Override
-    public <T> T unwrap(Class<T> iface) throws SQLException {
+    public <T> T unwrap(final Class<T> iface) throws SQLException {
         return null;
     }
 
@@ -899,7 +899,7 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
 
     @Override
-    public ResultSet getSchemas(String catalog, String schemaPattern)
+    public ResultSet getSchemas(final String catalog, final String schemaPattern)
     throws SQLException {
         return null;
     }
@@ -920,23 +920,23 @@ public class TesterDatabaseMetaData implements DatabaseMetaData {
     }
     
     @Override
-    public ResultSet getFunctionColumns(String catalog, String schemaPattern,
-            String functionNamePattern, String columnNamePattern)
+    public ResultSet getFunctionColumns(final String catalog, final String schemaPattern,
+            final String functionNamePattern, final String columnNamePattern)
             throws SQLException {
         return null;
     }
 
     @Override
-    public ResultSet getFunctions(String catalog, String schemaPattern,
-            String functionNamePattern) throws SQLException {
+    public ResultSet getFunctions(final String catalog, final String schemaPattern,
+            final String functionNamePattern) throws SQLException {
         return null;
     }
 
     /* JDBC_4_ANT_KEY_END */
     
     @Override
-    public ResultSet getPseudoColumns(String catalog, String schemaPattern,
-            String tableNamePattern, String columnNamePattern)
+    public ResultSet getPseudoColumns(final String catalog, final String schemaPattern,
+            final String tableNamePattern, final String columnNamePattern)
             throws SQLException {
         return null;
     }
